肖申克的救赎 (豆瓣)
Description: 肖申克的救赎电影简介和剧情介绍,肖申克的救赎影评、图片、预告片、影讯、论坛、在线购票
Keywords: 肖申克的救赎,The Shawshank Redemption,肖申克的救赎影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.1豆瓣电影Top250

# 肖申克的救赎 The Shawshank Redemption (1994)

更新描述或海报

导演: 弗兰克·德拉邦特
编剧: 弗兰克·德拉邦特 / 斯蒂芬·金
主演: 蒂姆·罗宾斯 / 摩根·弗里曼 / 鲍勃·冈顿 / 威廉姆·赛德勒 / 克兰西·布朗 / 吉尔·贝罗斯 / 马克·罗斯顿 / 詹姆斯·惠特摩 / 杰弗里·德曼 / 拉里·布兰登伯格 / 尼尔·吉恩托利 / 布赖恩·利比 / 大卫·普罗瓦尔 / 约瑟夫·劳格诺 / 祖德·塞克利拉 / 保罗·麦克兰尼 / 芮妮·布莱恩 / 阿方索·弗里曼 / V·J·福斯特 / 弗兰克·梅德拉诺 / 马克·迈尔斯 / 尼尔·萨默斯 / 耐德·巴拉米 / 布赖恩·戴拉特 / 唐·麦克马纳斯
类型: 剧情 / 犯罪
制片国家/地区: 美国
语言: 英语
上映日期: 1994-09-10(多伦多电影节) / 1994-10-14(美国)
片长: 142分钟
又名: 月黑高飞(港) / 刺激1995(台) / 地狱诺言 / 铁窗岁月 / 消香克的救赎
IMDb: tt0111161
豆瓣评分
引用
9.7
2740215人评价
5星
85.8%
4星
12.8%
3星
1.2%
2星
0.1%
1星
0.1%
好友评分
你关注的人看过这部作品的平均分
9.4
7人评价
好于 99% 剧情片
好于 99% 犯罪片
我看过这部电影 2020-07-14 修改
我的评价:
推荐

## 肖申克的救赎的剧情简介 · · · · · ·

一场谋杀案使银行家安迪（蒂姆•罗宾斯 Tim Robbins 饰）蒙冤入狱，谋杀妻子及其情人的指控将囚禁他终生。在肖申克监狱的首次现身就让监狱“大哥”瑞德（摩根•弗里曼 Morgan Freeman 饰）对他另眼相看。瑞德帮助他搞到一把石锤和一幅女明星海报，两人渐成患难 之交。很快，安迪在监狱里大显其才，担当监狱图书管理员，并利用自己的金融知识帮助监狱官避税，引起了典狱长的注意，被招致麾下帮助典狱长洗黑钱。偶然一次，他得知一名新入狱的小偷能够作证帮他洗脱谋杀罪。燃起一丝希望的安迪找到了典狱长，希望他能帮自己翻案。阴险伪善的狱长假装答应安迪，背后却派人杀死小偷，让他唯一能合法出狱的希望泯灭。沮丧的安迪并没有绝望，在一个电闪雷鸣的风雨夜，一场暗藏几十年的越狱计划让他自我救赎，重获自由！老朋友瑞德在他的鼓舞和帮助下，也勇敢地奔向自由。
本片获得1995年奥... (展开全部) 一场谋杀案使银行家安迪（蒂姆•罗宾斯 Tim Robbins 饰）蒙冤入狱，谋杀妻子及其情人的指控将囚禁他终生。在肖申克监狱的首次现身就让监狱“大哥”瑞德（摩根•弗里曼 Morgan Freeman 饰）对他另眼相看。瑞德帮助他搞到一把石锤和一幅女明星海报，两人渐成患难 之交。很快，安迪在监狱里大显其才，担当监狱图书管理员，并利用自己的金融知识帮助监狱官避税，引起了典狱长的注意，被招致麾下帮助典狱长洗黑钱。偶然一次，他得知一名新入狱的小偷能够作证帮他洗脱谋杀罪。燃起一丝希望的安迪找到了典狱长，希望他能帮自己翻案。阴险伪善的狱长假装答应安迪，背后却派人杀死小偷，让他唯一能合法出狱的希望泯灭。沮丧的安迪并没有绝望，在一个电闪雷鸣的风雨夜，一场暗藏几十年的越狱计划让他自我救赎，重获自由！老朋友瑞德在他的鼓舞和帮助下，也勇敢地奔向自由。
本片获得1995年奥斯卡10项提名，以及金球奖、土星奖等多项提名。 ©豆瓣

## 肖申克的救赎的演职员 · · · · · · ( 全部 43 )

- 弗兰克·德拉邦特 导演
- 蒂姆·罗宾斯 饰 安迪·杜佛兰 Andy Dufresne
- 摩根·弗里曼 饰 艾利斯·波伊德·“瑞德”·瑞丁 Ellis Boyd 'Red' Redding
- 鲍勃·冈顿 饰 监狱长山姆·诺顿 Warden Norton
- 威廉姆·赛德勒 饰 海伍德 Heywood
- 克兰西·布朗 饰 上尉哈德利 Captain Hadley

## 肖申克的救赎的视频和图片 · · · · · · ( 预告片2 | 视频评论3 · 添加 | 图片1046 · 添加 )

## 肖申克的救赎的获奖情况 · · · · · · ( 全部 )

- 第67届奥斯卡金像奖
- 最佳影片(提名)
- 妮基·马文

- 第52届金球奖
- 电影类 剧情片最佳男主角(提名)
- 摩根·弗里曼

- 第19届日本电影学院奖
- 最佳外语片

## 喜欢这部电影的人也喜欢 · · · · · ·

  阿甘正传

  当幸福来敲门

  三傻大闹宝莱坞

  摔跤吧！爸爸

  贫民窟的百万富翁

  荒岛余生

  心灵捕手

  国王的演讲

  死亡诗社

  美丽心灵

我要写短评

## 肖申克的救赎的短评 · · · · · · ( 全部 539086 条 )

热门 / 最新 / 好友

### 20272 有用 犀牛 看过 2005-10-28 00:28:07

当年的奥斯卡颁奖礼上，被如日中天的《阿甘正传》掩盖了它的光彩，而随着时间的推移，这部电影在越来越多的人们心中的地位已超越了《阿甘》。每当现实令我疲惫得产生无力感，翻出这张碟，就重获力量。毫无疑问，本片位列男人必看的电影前三名！回顾那一段经典台词：“有的人的羽翼是如此光辉，即使世界上最黑暗的牢狱，也无法长久地将他围困！”

### 33499 有用 kingfish 看过 2006-03-22 12:38:09

不需要女主角的好电影

### 22118 有用 如小果 看过 2008-02-27 21:43:23

恐惧让你沦为囚犯，希望让你重获自由。——《肖申克的救赎》

### 10713 有用 Eve|Classified 看过 2008-05-09 23:15:34

“这是一部男人必看的电影。”人人都这么说。但单纯从性别区分，就会让这电影变狭隘。《肖申克的救赎》突破了男人电影的局限，通篇几乎充满令人难以置信的温馨基调，而电影里最伟大的主题是“希望”。 当我们无奈地遇到了如同肖申克一般囚禁了心灵自由的那种囹圄，我们是无奈的老布鲁克，灰心的瑞德，还是智慧的安迪？运用智慧，信任希望，并且勇敢面对恐惧心理，去打败它？ 经典的电影之所以经典，因为他们都在做同一件事—... “这是一部男人必看的电影。”人人都这么说。但单纯从性别区分，就会让这电影变狭隘。《肖申克的救赎》突破了男人电影的局限，通篇几乎充满令人难以置信的温馨基调，而电影里最伟大的主题是“希望”。 当我们无奈地遇到了如同肖申克一般囚禁了心灵自由的那种囹圄，我们是无奈的老布鲁克，灰心的瑞德，还是智慧的安迪？运用智慧，信任希望，并且勇敢面对恐惧心理，去打败它？ 经典的电影之所以经典，因为他们都在做同一件事——让你从不同的角度来欣赏希望的美好。 (展开)

### 3895 有用 文泽尔 看过 2008-01-14 01:53:08

人的生命不过是从一个洞穴通往另一个世界..然后在那个世界的雨中继续颤抖.i hope

> 更多短评 539086条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。

### 0 有用 黑烟的圈 看过 2020-08-13 11:14:25

小小的汤勺有大大的梦想。

### 1 有用 LLudeer 看过 2013-12-15 15:38:48

Hope is a good thing, and maybe the best thing of all.

我要写影评

## 肖申克的救赎的影评 · · · · · · ( 全部 12424 条 )

热门 / 最新 / 好友
大头绿豆 2005-05-12 20:44:13

## 十年·肖申克的救赎

距离斯蒂芬·金（Stephen King）和德拉邦特（Frank Darabont）们缔造这部伟大的作品已经有十年了。我知道美好的东西想必大家都能感受，但是很抱歉，我的聒噪仍将一如既往。 在我眼里，肖申克的救赎与信念、自由和友谊有关。 ［1］信 念 瑞德（Red）说，希望是危险的东西，是精... (展开)
17963 719 1019回应 收起
隱居雲上 2005-07-12 11:23:39

## 终于找到了郁闷人生的原因――观《肖申克的救赎》有感

周末看了一部美国影片《肖申克的救赎》（《The Shawshank Redemption》） 讲的是一位因冤案入狱的年轻银行家在牢中如何追寻自由的故事。 不同的人看同样的影片可能都有不同的感受。对于目前无力改变现状的我，看完这部影片后最深的感受就是：才华、毅力两样，是任何人在任何境... (展开)
12322 784 924回应 收起
泠十三 2019-07-29 12:54:13 #《肖申克的救赎》到底“救赎”了什么？

## 《肖申克的救赎》到底“救赎”了什么？

这篇影评可能有剧透

原文转自：[我们都是肖申克里等待救赎的灵魂] 01 “你来对地方了，这里人人都无罪。” Red笑着对Andy说。 这个杀妻的银行家，因谋杀妻子和她的情夫，被判处终身监禁。 尽管被关进了这座叫肖申克的监狱，他依然极力否认。 犯人经过审判，被判处有罪，他们被关进监狱。 在这里，... (展开)
4291 9 134回应 收起
aratana 2007-02-26 10:38:45

## 《肖申克的救赎》：1994—2007，希望就是现实

一、缘起 从来没想过给《肖申克的救赎》写一篇影评，也许是生怕暴露自己只是个不谙世事的初级影迷，也许是对这样一部无法复制的影片真的不愿去过多地提起。然而一场出其不意的重感冒让我只能卧床裹被，已没有了力气去消化我那些故作高深、一直收着却懒得去看的电影，不期然地... (展开)
2019 157 202回应 收起
蓑笠翁 2005-09-25 16:27:41

## 人生的过程就是一个摆脱institutionalization(体制化)的过程

现在好象比较时兴将人分为体制内和体制外的人,体制外的人通常有某种优越感,似乎自己的人格才是独立的.可实际上,真正愿意做体制外的人还是很少的,而且是很痛苦的.余杰北大硕士毕业后差一点进了他想进的国家图书馆作一个体制内的人,可由于他写了一些比较反体制的文章,最后还是被... (展开)
1319 73 155回应 收起
油爆虾 2006-08-03 23:24:54

## 《肖申克的救赎》的一些幕后花絮

* 是否记得片尾有一行字幕"In memory of Allen Greene"？翻译成中文就是"纪念Allen Greene "。Allen Greene是《肖申克的救赎》编导Frank Darabont的经纪人，在影片完成 的前夕死于AIDS的并发症。 　　 　　* 是否记得刚来到监狱的新囚犯们走下囚车时，嘲笑他们的人群中有一个... (展开)
797 38 63回应 收起
豆泽宇瓣 2017-10-05 22:18:05

## 关于“救赎”

这篇影评可能有剧透

个人感觉，《肖申克的救赎》（The Shawshank Redemption）中的Redemption的意思是“赎回;偿还;补救”，因此“救赎”非常完美地解释了这部电影的主题，围绕“救赎”主题的是： 1，安迪对自己的救赎：从一开始不让自己沦陷于监狱生活（对比于和他同时入狱的胖子第一晚就受不了）... (展开)
1135 82 19回应 收起
附离 2012-05-31 22:40:33

## 没能力自由，谈什么自由 —— 其实你没那么渴望自由

打一颗星并不是因为这部片很差，只是不明白怎么会是豆瓣电影里的头牌。用极端的踩来平衡下极端的捧。 N年前看的片子，当时觉得真不错。具体不错在哪里？或许是因为结局不错，主人公最终成功越狱到达梦想之地，观影者借以给自己希望，以为自己也能达到自由的彼处。 第一次看完... (展开)
2345 1405 626回应 收起
無腳之鳥. 2016-12-26 20:56:11 #《肖申克的救赎》到底“救赎”了什么？

## 思想改变人生

这篇影评可能有剧透

今天是我第二次看这部电影 第一次看的时候我才十五岁，那时阅片量少，所以没有怎么看到这部电影的意义所在。只是觉得安迪好牛掰噢！然后就没有然后了 今天重看经典，真是涨了不少知识。安迪的那种精神着实让人敬畏，即使你身在监狱里，即使被判了终身监禁，你也不能对生活失去... (展开)
929 49 54回应 收起

> 更多影评 12424篇

添加新讨论

## 讨论区 · · · · · ·

看完后有一定要把金融和会计学好的决心 | 来自Tututu | 13 回应 | 2022-11-24 19:55:06
全面不如教父 | 来自The Lost Man | 1 回应 | 2022-11-24 01:14:35
安迪最后杀了瑞德 | 来自小小兔 | 65 回应 | 2022-11-24 00:37:51
我一直不明白，这部片子的意义在哪里？如果是教你... | 来自liyazhou1988 | 165 回应 | 2022-11-24 00:36:31
没有体验过生活的荒诞的人很难真正理解这部电影。 | 来自西西弗斯之旅 | 3 回应 | 2022-11-22 20:16:36

> 去这部影片的讨论区（全部3178条）

## 关于《肖申克的救赎》的问题 · · · · · · ( 全部88个 )

- Red之前那么多次为什么都没有批准，最后愤怒却被批？ 53人回答
- Andy为什么不凿好隧道就逃走？ 14人回答

> 全部88个问题

## 在哪儿看这部电影 · · · · · ·

报错

- 优酷视频 VIP免费观看
- 爱奇艺视频 VIP免费观看
- 腾讯视频 VIP免费观看
- 哔哩哔哩 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【励志电影】 (影志)
- 他们是高智商玩家 (中间元素)
- 那些和谐的腐剧，腐动画，腐电影们。 (墨 尘)
- 经典商业与法律电影 (passionfly)

## 谁在看这部电影 · · · · · ·

- 清奈
  刚刚 看过
- momo
  刚刚 看过
- Хайр🦋
  刚刚 看过

4419704人看过 / 433560人想看

订阅肖申克的救赎的评论:
feed: rss 2.0